@@ -130,13 +130,12 @@ def run(
 
     temp_dir = tempfile.mkdtemp()
     copy_tree(os.getcwd(), str(temp_dir))
+    notebooks_files = treebeard_config.get_deglobbed_notebooks()
     try:
-        subprocess.check_output(
-            ["nbstripout"] + treebeard_config.deglobbed_notebooks, cwd=temp_dir
-        )
+        subprocess.check_output(["nbstripout"] + notebooks_files, cwd=temp_dir)
     except:
         fatal_exit(f"Failed to nbstripout a notebook! Do you have an invalid .ipynb?")
-    click.echo(treebeard_config.deglobbed_notebooks)
+    click.echo(notebooks_files)
     click.echo("🌲  Compressing Repo")
 
     with tempfile.NamedTemporaryFile(
@@ -222,7 +221,10 @@ def run(
             time.sleep(5)
             response = requests.get(notebooks_endpoint, headers=treebeard_env.dict())
             json_data = json.loads(response.text)
-            status = json_data["runs"][-1]["status"]
+            if len(json_data["runs"]) == 0:
+                status = "FAILURE"
+            else:
+                status = json_data["runs"][-1]["status"]
             click.echo(f"{get_time()} Build status: {status}")
             if status == "SUCCESS":
                 build_result = status
@@ -276,8 +278,13 @@ def status():
 
         mechanism: str = run.trigger["mechanism"]
         ran_via = "" if len(mechanism) == 0 else f"via {mechanism}"
+        try:
+            branch = f"🔀{run.trigger['branch']}"
+        except:
+            branch = ""
+
         click.echo(
-            f"  {status_emoji[run.status]}  {time_string} {ran_via} -- {run.url}"
+            f"  {status_emoji[run.status]}  {time_string} {ran_via} {branch} -- {run.url}"
         )
 
     if "schedule" in json_data:
